==> ext_info-1.2.tar.bz2: ext_info/translations/ext_info_pl.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>@default</name>
    <message>
        <source>Remind</source>
        <translation>Przypominaj</translation>
    </message>
    <message>
        <source>Enable to remind of name day</source>
        <translation>Przypominaj o imieninach</translation>
    </message>
    <message>
        <source>Enable to remind of birthday</source>
        <translation>Przypominaj o urodzinach</translation>
    </message>
    <message>
        <source>Remind days before:</source>
        <translation>Informuj dni przed:</translation>
    </message>
    <message>
        <source>Reminds frequency (minutes):</source>
        <translation>Częstotliwość przypominania (w minutach):</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importuj</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Eksportuj</translation>
    </message>
</context>
<context>
    <name>ExtInfo</name>
    <message>
        <source> have name day for </source>
        <translation> ma imieniny za </translation>
    </message>
    <message>
        <source> days</source>
        <translation> dni</translation>
    </message>
    <message>
        <source> have name day</source>
        <translation> ma dziś imieniny</translation>
    </message>
    <message>
        <source> have birthday for </source>
        <translation> ma urodziny za </translation>
    </message>
    <message>
        <source> have birthday</source>
        <translation> ma dziś urodziny</translation>
    </message>
    <message>
        <source>Display extended information</source>
        <translation>Rozszerzone informacje o kontaktcie</translation>
    </message>
    <message>
        <source>I know about birthday :)</source>
        <translation>Wiem o urodzinach :)</translation>
    </message>
    <message>
        <source>I know about name day :)</source>
        <translation>Wiem o imieninach :)</translation>
    </message>
    <message>
        <source>First you must close ExtInfo window</source>
        <translation>Najpierw musisz zamknąć okno ExtInfo</translation>
    </message>
    <message>
        <source>RExInfo/ExtInfo 1.x files</source>
        <translation>Pliki RExInfo/ExtInfo 1.x</translation>
    </message>
    <message>
        <source>This file are exists. Overwrite this file?</source>
        <translation>Plik już istnieje i jego poprzednia zawartość zostanie zamazana. Czy kontynuować?</translation>
    </message>
    <message>
        <source>Error write file</source>
        <translation>Błąd zapisu pliku</translation>
    </message>
    <message>
        <source>Error read file</source>
        <translation>Błąd odczytu pliku</translation>
    </message>
</context>
<context>
    <name>frmExtInfo</name>
    <message>
        <source>Extension info</source>
        <translation>Rozrzerzone informacje</translation>
    </message>
    <message>
        <source>Format: dd.mm.yyyy</source>
        <translation>Format: dd.mm.rrrr</translation>
    </message>
    <message>
        <source>Phone number</source>
        <translation>Numer telefonu domowego</translation>
    </message>
    <message>
        <source>Phone:</source>
        <translation>Telefon:</translation>
    </message>
    <message>
        <source>Section:</source>
        <translation>Sekcja:</translation>
    </message>
    <message>
        <source>Birthday:</source>
        <translation>Data urodzenia:</translation>
    </message>
    <message>
        <source>First name:</source>
        <translation>Imię:</translation>
    </message>
    <message>
        <source>Name day:</source>
        <translation>Data imienin:</translation>
    </message>
    <message>
        <source>Nickname:</source>
        <translation>Pseudonim:</translation>
    </message>
    <message>
        <source>Cellular phone number</source>
        <translation>Numer komórki</translation>
    </message>
    <message>
        <source>Mobile:</source>
        <translation>Komórka:</translation>
    </message>
    <message>
        <source>Format: dd.mm</source>
        <translation>Format: dd.mm</translation>
    </message>
    <message>
        <source>Last name:</source>
        <translation>Nazwisko:</translation>
    </message>
    <message>
        <source>Interests:</source>
        <translation>Zainteresowania:</translation>
    </message>
    <message>
        <source>Remove description</source>
        <translation>Usuń opis</translation>
    </message>
    <message>
        <source>Get data from Kadu</source>
        <translation>Pobierz z Kadu</translation>
    </message>
    <message>
        <source>Home adress</source>
        <translation>Adres domowy:</translation>
    </message>
    <message>
        <source>Street and home number</source>
        <translation>Nazwa ulicy/wsi i numer domu</translation>
    </message>
    <message>
        <source>Street:</source>
        <translation>Ulica:</translation>
    </message>
    <message>
        <source>City:</source>
        <translation>Miasto:</translation>
    </message>
    <message>
        <source>Zip and City</source>
        <translation>Kod pocztowy i miasto</translation>
    </message>
    <message>
        <source>Info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Second GG:</source>
        <translation>Drugi numer GG:</translation>
    </message>
    <message>
        <source>Tlen Nick:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ICQ UIN:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>WP Kontakt:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>E-mail:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>IRC Nick:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>E-mail(2):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>WWW:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Net</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>0 chars</source>
        <translation>0 znaków</translation>
    </message>
    <message>
        <source>Memo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Path image:</source>
        <translation>Ścieżka do zdjęcia:</translation>
    </message>
    <message>
        <source>Load image</source>
        <translation>Otwórz zdjęcie</translation>
    </message>
    <message>
        <source>Remove image</source>
        <translation>Usuń zdjęcie</translation>
    </message>
    <message>
        <source>Scaled</source>
        <translation>Dopasuj do okna</translation>
    </message>
    <message>
        <source>Photo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Informacje</translation>
    </message>
    <message>
        <source> chars, Warning!!! This memo have over 1024 chars. It isn&apos;t compatible with RExInfo!</source>
        <translation> znaków, Uwaga!!! Memo zawiera więcej niż 1024 znaków. Mogą być problemy po exporcie do RExInfo!</translation>
    </message>
    <message>
        <source> chars</source>
        <translation> znaków</translation>
    </message>
    <message>
        <source>Error: Bad format birthday date, pleas write in format: dd.mm.yyyy</source>
        <translation>Błąd: Zły format zapisu daty urodzenia. Data musi być w formacie: dd.mm.rrrr</translation>
    </message>
    <message>
        <source>Error: Bad format nameday date, pleas write in format: dd.mm</source>
        <translation>Błąd: Zły format zapisu daty imienin. Data musi być w formacie: dd.mm</translation>
    </message>
    <message>
        <source>This module is compatible with RExInfo plugin from PowerGG.</source>
        <translation>Moduł zachowuje kompatybilność formatu zapisu pliku z pluginem RExInfo z pakietu PowerGG.</translation>
    </message>
    <message>
        <source>Path image: </source>
        <translation>Ścieżka do zdjęcia: </translation>
    </message>
    <message>
        <source>All Pixmaps</source>
        <translation>Wszystkie obrazy</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Wszystkie pliki</translation>
    </message>
</context>
</TS>

==> ext_info-1.4.3.tar.bz2: ext_info/translations/ext_info_pl.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>@default</name>
    <message>
        <source>Remind</source>
        <translation>Przypominaj</translation>
    </message>
    <message>
        <source>Enable to remind of name day</source>
        <translation>Przypominaj o imieninach</translation>
    </message>
    <message>
        <source>Enable to remind of birthday</source>
        <translation>Przypominaj o urodzinach</translation>
    </message>
    <message>
        <source>Remind days before:</source>
        <translation>Informuj dni przed:</translation>
    </message>
    <message>
        <source>Reminds frequency (minutes):</source>
        <translation>Częstotliwość przypominania (w minutach):</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importuj</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Eksportuj</translation>
    </message>
</context>
<context>
    <name>ExtInfo</name>
    <message>
        <source> has name-day in </source>
        <translation> ma imieniny za </translation>
    </message>
    <message>
        <source> has name-day tomorrow</source>
        <translation> ma jutro imieniny</translation>
    </message>
    <message>
        <source> days</source>
        <translation> dni</translation>
    </message>
    <message>
        <source> day</source>
        <translation> dzień</translation>
    </message>
    <message>
        <source> has name-day</source>
        <translation> ma dziś imieniny</translation>
    </message>
    <message>
        <source> has birthday in </source>
        <translation> ma urodziny za </translation>
    </message>
    <message>
        <source> has birthday tomorrow</source>
        <translation> ma jutro urodziny</translation>
    </message>
    <message>
        <source> has birthday</source>
        <translation> ma dziś urodziny</translation>
    </message>
    <message>
        <source>Display extended information</source>
        <translation>Rozszerzone informacje o kontaktcie</translation>
    </message>
    <message>
        <source>I know about birthday :)</source>
        <translation>Wiem o urodzinach :)</translation>
    </message>
    <message>
        <source>I know about name day :)</source>
        <translation>Wiem o imieninach :)</translation>
    </message>
    <message>
        <source>First you must close ext_info window</source>
        <translation>Najpierw musisz zamknąć okno ext_info</translation>
    </message>
    <message>
        <source>RExInfo/ext_info 1.x files</source>
        <translation>Pliki RExInfo/ext_info 1.x</translation>
    </message>
    <message>
        <source>This file are exists. Overwrite this file?</source>
        <translation>Plik już istnieje i jego poprzednia zawartość zostanie zamazana. Czy kontynuować?</translation>
    </message>
    <message>
        <source>Error write file</source>
        <translation>Błąd zapisu pliku</translation>
    </message>
    <message>
        <source>Error read file</source>
        <translation>Błąd odczytu pliku</translation>
    </message>
</context>
<context>
    <name>frmExtInfo</name>
    <message>
        <source>Extension info</source>
        <translation>Rozszerzone informacje</translation>
    </message>
    <message>
        <source>Format: dd.mm.yyyy</source>
        <translation>Format: dd.mm.rrrr</translation>
    </message>
    <message>
        <source>Phone number</source>
        <translation>Numer telefonu domowego</translation>
    </message>
    <message>
        <source>Phone:</source>
        <translation>Telefon:</translation>
    </message>
    <message>
        <source>Section:</source>
        <translation>Sekcja:</translation>
    </message>
    <message>
        <source>Birthday:</source>
        <translation>Data urodzenia:</translation>
    </message>
    <message>
        <source>First name:</source>
        <translation>Imię:</translation>
    </message>
    <message>
        <source>Name day:</source>
        <translation>Data imienin:</translation>
    </message>
    <message>
        <source>Nickname:</source>
        <translation>Pseudonim:</translation>
    </message>
    <message>
        <source>Cellular phone number</source>
        <translation>Numer komórki</translation>
    </message>
    <message>
        <source>Mobile:</source>
        <translation>Komórka:</translation>
    </message>
    <message>
        <source>Format: dd.mm</source>
        <translation>Format: dd.mm</translation>
    </message>
    <message>
        <source>Last name:</source>
        <translation>Nazwisko:</translation>
    </message>
    <message>
        <source>Interests:</source>
        <translation>Zainteresowania:</translation>
    </message>
    <message>
        <source>Remove description</source>
        <translation>Usuń opis</translation>
    </message>
    <message>
        <source>Get data from Kadu</source>
        <translation>Pobierz z Kadu</translation>
    </message>
    <message>
        <source>Home adress</source>
        <translation>Adres domowy:</translation>
    </message>
    <message>
        <source>Street and home number</source>
        <translation>Nazwa ulicy/wsi i numer domu</translation>
    </message>
    <message>
        <source>Street:</source>
        <translation>Ulica:</translation>
    </message>
    <message>
        <source>City:</source>
        <translation>Miasto:</translation>
    </message>
    <message>
        <source>Zip and City</source>
        <translation>Kod pocztowy i miasto</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Główne</translation>
    </message>
    <message>
        <source>Second GG:</source>
        <translation>Drugi numer GG:</translation>
    </message>
    <message>
        <source>Tlen Nick:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ICQ UIN:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>WP Kontakt:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>E-mail:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>IRC Nick:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>E-mail(2):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>WWW:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Net</source>
        <translation>Internet</translation>
    </message>
    <message>
        <source>0 chars</source>
        <translation>0 znaków</translation>
    </message>
    <message>
        <source>Memo</source>
        <translation>Notatki</translation>
    </message>
    <message>
        <source>Path image:</source>
        <translation>Ścieżka do zdjęcia:</translation>
    </message>
    <message>
        <source>Load image</source>
        <translation>Otwórz zdjęcie</translation>
    </message>
    <message>
        <source>Remove image</source>
        <translation>Usuń zdjęcie</translation>
    </message>
    <message>
        <source>Scaled</source>
        <translation>Dopasuj do okna</translation>
    </message>
    <message>
        <source>Photo</source>
        <translation>Zdjęcie</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Informacje</translation>
    </message>
    <message>
        <source> chars, Warning!!! This memo have over 1024 chars. It isn&apos;t compatible with RExInfo!</source>
        <translation> znaków, Uwaga!!! Memo zawiera więcej niż 1024 znaków. Mogą być problemy po exporcie do RExInfo!</translation>
    </message>
    <message>
        <source> chars</source>
        <translation> znaków</translation>
    </message>
    <message>
        <source>Error: Bad format birthday date, pleas write in format: dd.mm.yyyy</source>
        <translation>Błąd: Zły format zapisu daty urodzenia. Data musi być w formacie: dd.mm.rrrr</translation>
    </message>
    <message>
        <source>Error: Bad format nameday date, pleas write in format: dd.mm</source>
        <translation>Błąd: Zły format zapisu daty imienin. Data musi być w formacie: dd.mm</translation>
    </message>
    <message>
        <source>This module is compatible with RExInfo plugin from PowerGG.</source>
        <translation>Moduł zachowuje kompatybilność formatu zapisu pliku z pluginem RExInfo z pakietu PowerGG.</translation>
    </message>
    <message>
        <source>Path image: </source>
        <translation>Ścieżka do zdjęcia: </translation>
    </message>
    <message>
        <source>All Pixmaps</source>
        <translation>Wszystkie obrazy</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Wszystkie pliki</translation>
    </message>
    <message>
        <source>Dzwiedziu</source>
        <translation>Dźwiedziu</translation>
    </message>
    <message>
        <source>This section have modified:</source>
        <translation>Te sekcje zostały zmienione:</translation>
    </message>
    <message>
        <source>Do you want to save changes?</source>
        <translation>Czy chcesz zachować zmiany?</translation>
    </message>
</context>
</TS>
